Power Profiler
==============

[![](https://img.shields.io/pypi/v/power-profiler.svg)](https://pypi.org/project/power-profiler/)

A power profiling utility for Makerdiary nRF52840 M.2 Developer Kit.

![](https://github.com/makerdiary/power-profiler/raw/master/preview.png)

## Requirements
+ pyserial
+ pyqtgraph
+ pyqt5 or pyside2

## Install
```
pip install pyqt5 power-profiler
```

On Windows, you can download the pre-built app from [the release page](https://github.com/makerdiary/power-profiler/releases)

## Run
```
power-profiler
```




